@@ -7,7 +7,7 @@ from urllib.request import urlopen
 from shutil import copyfileobj
 from validations import mutgen_validate
 
-MUTGEN_DOCKER_IMG = os.environ.get("MUTGEN_DOCKER_IMG", "harbor.lji.org/iedb-public/mutgen:v0.2.1-beta")
+MUTGEN_DOCKER_IMG = os.environ.get("MUTGEN_DOCKER_IMG", "harbor.lji.org/iedb-public/mutgen:v0.6-beta")
 
 SELECTED_COLUMNS = ["mutgen.variant_id", "mutgen.variant_type", "mutgen.chr", "mutgen.position", "mutgen.ref_seq", "mutgen.alt_seq", "mutgen.effect", "mutgen.gene_name", "mutgen.gene_id", "mutgen.protein_ref", "mutgen.protein_alt", 
                     "mutgen.protein_position", "mutgen.peptide", "mutgen.peptide_warnings", "mutgen.hgvs_ref_allele", "mutgen.hgvs_tum_allele", "mutgen.[PEPTIDELENGTH]mer_ref_peptides", "mutgen.[PEPTIDELENGTH]mer_mut_peptides", "mutgen.mutation_position_in_peptide"
@@ -183,6 +183,9 @@ def generate_mut(**kwargs):
         dict_result = tsv_to_dict(os.path.join(tsv_dir, tsv_file_name))
         del dict_result['index']
         dict_result['result_type'] = '_'.join(filter(None, tsv_file_name.replace('.tsv', '').replace('all', '').replace('output', '').replace(tsv_dir_name, '').split('_')))
+        # rename result_type 'snp' to 'variant'
+        if dict_result['result_type'] == 'snp':
+            dict_result['result_type'] = 'variant'
         dict_result['table_columns'] = dict_result.pop('columns')
         dict_result['table_data'] = sorted(dict_result.pop('data'))
         # check if table_data is empty
@@ -194,8 +197,8 @@ def generate_mut(**kwargs):
     # reuturn the info about possible reasons for no generated peptides
     if has_empty_table:
         warnings.append("Possible reasons for no generated peptides include a mismatch between the selected 'reference genome' and the genome used in the VCF file as well as variants that are in non-coding regions.")
-    # Type order: 'Unique peptde', 'peptide', 'SNP'
-    type_sort_order = 'ups'
+    # Type order: 'Unique peptde', 'peptide', 'variant'(renamed from 'SNP')
+    type_sort_order = 'upvs'
     results.sort(key=lambda d:(str(type_sort_order.index(d['result_type'][0]))+d['result_type'][1:]) if d['result_type'][0] in type_sort_order else d['result_type'])
     #print([(type(r),r['result_type'],r['table_columns']) for r in results])
     return {"results": results, "errors": errors, "warnings": warnings}
